# Kinesis Java Record Lambda Forwarder

This project contains sample AWS Lambda functions that will read events from an input Kinesis stream and forward them to another Kinesis stream (potentially in a different AWS account).  This project contains Java-based AWS Lambda functions which you can use as a template to build new applications on AWS Lambda that read from a Kinesis stream and forward to another Kinesis stream.

## Lambda Aggregating Forwarder

The Lambda function `LambdaAggregatingForwarder.java` is a Java-based AWS Lambda function that will read from a Kinesis stream, deaggregate incoming records (if necessary), optimally aggregated them and forward them to another Kinesis stream (potentially in another AWS account).

### Permissions 

If you're forwarding Kinesis records to another Kinesis stream in the same AWS account as the AWS Lambda function, then you simply need to configure the IAM Role for the AWS Lambda function to have permissions to publish to the stream.

If the Kinesis stream you need to publish to is in a different AWS account than where your AWS Lambda function is running, it's a bit trickier since Kinesis doesn't currently have an easy way to provide cross-account publishing permissions.  You need to create (or have someone create for you) an IAM Role in the same AWS account as the destination Kinesis Stream that has permissions to publish to that stream.  Then you must also configure your AWS Lambda function's runtime role to be able to assume the IAM publishing role from the other account.  Note that there's setup required in BOTH AWS accounts to get the "assumeRole" permission working properly.

### Instructions for Use

1. Modify the `DESTINATION_STREAM_NAME` and `DESTINATION_STREAM_REGION` variables in `LambdaAggregatingForwarder.java` to point to the Kinesis stream and region where you will be forwarding records.  Optionally modify the `DESTINATION_CONNECTION_TIMEOUT` and `DESTINATION_SOCKET_TIMEOUT` as well.
2. If you are forwarding records to a Kinesis stream in the same AWS account as the AWS Lambda function, skip to step 3.  Otherwise you'll want to comment out the line that creates a simple `DefaultAWSCredentialsProviderChain()` and uncomment the line that creates an `STSAssumeRoleSessionCredentialsProvider` and fill in the associated Role ARN.  See the "Permissions" section above for details.
3. Run Maven->Install to build the project
4. Create a new Lambda function in your AWS account
5. Skip blueprint selection
6. Choose Java 8 as the runtime
7. Choose the built file (from step #2) KinesisLambdaForwarder-1.0-lambda.jar as the code for the function (NOT the KinesisLambdaForwarder-1.0.jar file).
8. Choose com.amazonaws.kinesis.forwarder.LambdaAggregatingForwarder::handleRequest as the Handler
9. Set the default batch size as required for your Kinesis stream throughput
10. Set the Role, Memory and Timeout appropriately.
11. Connect your new Lambda function to the Kinesis stream you'll be reading from

----

Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
